Search.setIndex({filenames:["index","autologging","examples"],envversion:43,objects:{"":{autologging:[1,0,0,"-"]},autologging:{traced:[1,1,1,""],TracedMethods:[1,1,1,""],TRACE:[1,2,1,""],logged:[1,1,1,""]}},objnames:{"0":["py","module","Python module"],"1":["py","function","Python function"],"2":["py","data","Python data"]},terms:{someth:0,"_test__logg":1,info:2,abov:2,wai:0,ensur:1,classmethod:[0,1,2],those:1,themselv:1,displai:1,stream:1,how:2,codebas:0,warn:2,treat:1,sourceforg:0,usag:0,determin:0,underscor:[0,1],user:1,around:0,appropri:0,get:0,log:1,def:[0,1,2],myclass:[0,1,2],project:0,neither:0,follow:[0,1,2],stack:0,upon:0,caller:0,"default":1,contain:2,help:0,my_method:2,written:1,doubl:1,staticmethod:[0,1,2],root:0,same:0,call:[1,2],creat:[0,1],directli:1,concept:0,start:0,util:0,simpli:[0,1],access:1,object:1,keyword:1,via:0,wish:1,were:1,green:1,releas:0,none:[1,2],self:[0,1,2],argument:1,add:1,set:2,explicitli:1,separ:[1,2],site:0,qualifi:0,search:0,modifi:2,privat:1,ani:0,handl:0,unittest:0,level:[0,1,2],regardless:1,stdout:1,all:0,write:0,my_modul:2,isn:0,respect:0,"_tracer":2,"import":[0,1,2],more:[0,2],necessari:0,myapp:2,egg:1,another_method:2,made:[0,1,2],run:0,tracedmethod:[0,1,2],"new":0,approach:0,maintain:0,reason:0,usual:0,entir:1,modulenam:0,levelnam:2,my_funct:[1,2],bitbucket:0,parent:1,either:0,statement:0,work:[0,1],spam:1,conflict:1,format:[1,2],inher:0,consist:[0,1],debug:[0,1,2],basicconfig:1,"while":2,whether:1,sourc:[0,1],exercis:2,my_classmethod:[0,1,2],quit:1,side:0,enabl:1,sent:1,prone:0,from:[0,2],context:0,"static":[0,2],unbound:1,"function":[0,1,2],suit:0,file:1,metaclass:[0,1,2],test:[0,1],therefor:1,recommend:0,"_logger":[0,1,2],avail:1,without:1,correctli:0,alwai:1,"__name__":[0,2],emploi:0,where:1,my_help:0,specif:1,show:2,need:2,"return":[1,2],modul:1,first:[1,2],than:[0,1],mai:1,produc:2,member:1,record:1,also:[0,1],my_instancemethod:[0,1],base:0,now:0,allow:[0,1],inner:[0,2],effect:0,thi:[0,1],messag:[1,2],correct:1,non:2,logger:1,binari:0,bit:0,onli:[1,2],addlevelnam:0,otherwis:1,could:1,configur:1,subclass:1,effort:0,out:0,ing:1,lower:[0,1],findcal:0,resembl:0,under:2,target:1,check:0,turn:0,requir:0,instanc:[0,1,2],frame:0,intern:0,clone:0,exampl:1,java:0,factori:[0,1],pleas:[0,1],defin:[0,2],syntax:[0,2],make:[0,1],robin:1,repositori:0,encapsul:0,order:2,mercuri:0,whose:1,assum:2,pip:0,batman:1,dot:1,though:0,my_inner_method:2,note:1,tracer:1,workaround:0,index:0,would:[1,2],setup:0,becom:0,my_staticmethod:[0,1,2],"_inner":0,analog:0,includ:1,python:[0,2],within:0,second:2,version:0,directori:0,method:[0,1,2],consid:1,automat:1,ham:1,expect:1,support:0,channel:1,built:0,awar:0,given:[0,2],standard:0,detail:0,obj:1,custom:1,inform:0,chang:[0,2],error:0,develop:0,can:0,when:0,item:1,you:0,coupl:0,pass:1,arg:1,sever:1,see:[0,1],challeng:0,nor:0,well:0,"__logger":[0,1,2],placehold:1,decor:[0,1],must:[0,1],page:0,control:2,provid:1,outer:0,fail:[0,1],hand:0,simpl:0,trace:1,tediou:0,distribut:0,languag:0,should:0,address:0,dynam:0,getlogg:[0,1,2],two:[0,2],which:0,each:2,have:1,rather:0,lead:0,name:1},titles:["Autologging &#8212; easier logging and tracing for classes","The <tt class=\"docutils literal\"><span class=\"pre\">autologging</span></tt> API","Examples of using <tt class=\"docutils literal\"><span class=\"pre\">autologging</span></tt>"],titleterms:{"class":[0,1,2],pre:[1,2],instal:0,"default":2,liter:[1,2],code:0,output:2,tabl:0,name:2,introduct:0,both:2,boilerpl:0,api:1,modul:[0,2],docutil:[1,2],trace:[0,2],indic:0,exampl:2,log:[0,2],differ:2,download:0,belong:0,logger:2,autolog:[0,1,2],span:[1,2],easier:0,content:0},objtypes:{"0":"py:module","1":"py:function","2":"py:data"}})